% torchlinops documentation master file, created by
% sphinx-quickstart on Fri Feb 16 01:34:36 2024.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

# torch-named-linops

Welcome to the documentation for `torch-named-linops`, a linear operator
abstraction designed for large-scale numerical computing, optimization, and
machine learning.


```{toctree}
:caption: 'Contents:'
:maxdepth: 1

installation
getting_started
linops
api
why_this_package
faq
```

## Other intersting packages
- SigPy
- MIRTorch
- sci-co
- matmri
- einops
- torch_linops
- PyLops
- linear_operator

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
